package ch.zhaw.projekt2.turnierverwaltung;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.logging.*;


public class LogConfiguration {
    private static final Logger logger = Logger.getLogger(LogConfiguration.class.getCanonicalName());
    private final File mainDir;

    public LogConfiguration(String saveLocation, String logFileLocation) throws IOException {
        logger.fine("Starts setting up a main directory in which a folder with the log files will be placed, if not already exists");
        this.mainDir = new File(saveLocation);
        if (!mainDir.exists()) {
            logger.fine("Creating main directory for log ordner in given path" + saveLocation);
            mainDir.mkdir();
        } else {
            logger.finer("main directory for log folder already exists");
        }

        File saves = new File(mainDir, "log_files");
        if (!saves.exists()) {
            saves.mkdir();
            logger.fine("Creating log save directory");
        } else {
            logger.finer("log save directory already exists");
        }

        String propertiesPath = "ch" + System.getProperty("file.separator") + "zhaw" + System.getProperty("file.separator") + "projekt2" + System.getProperty("file.separator") +
                "turnierverwaltung" + System.getProperty("file.separator") + "logging" + System.getProperty("file.separator") + "log.properties";

        logger.fine("Getting and reading logconfig file from " + propertiesPath);
        InputStream logConfig = this.getClass().getClassLoader().getResourceAsStream(propertiesPath);
        LogManager.getLogManager().readConfiguration(logConfig);


        Logger.getLogger(LogConfiguration.class.getPackageName());
    }
}
